@@ -35,9 +35,11 @@ WWW::CurlOO::Share - Perl interface for curl_share_* functions
 
  my $share = WWW::CurlOO::Share->new();
  $share->setopt( CURLSHOPT_SHARE, CURL_LOCK_DATA_COOKIE );
+ $share->setopt( CURLSHOPT_SHARE, CURL_LOCK_DATA_DNS );
 
- $easy1->setopt( CURLOPT_SHARE() => $share );
- $easy2->setopt( CURLOPT_SHARE() => $share );
+ $easy_one->setopt( CURLOPT_SHARE() => $share );
+
+ $easy_two->setopt( CURLOPT_SHARE() => $share );
 
 =head1 DESCRIPTION
 
@@ -76,12 +78,7 @@ VALUE depends on whatever that option expects.
  $share->setopt( CURLSHOPT_SHARE, CURL_LOCK_DATA_COOKIE );
 
 Calls L<curl_share_setopt(3)>.
-
-=item DESTROY( )
-
-Cleans up. It should not be called manually.
-
-Calls L<curl_share_cleanup(3)>.
+Throws L</WWW::CurlOO::Share::Code> on error.
 
 =back
 
@@ -147,13 +144,18 @@ CURLSHOPT_USERDATA value. Easy may be undefined in some cases.
 
 =back
 
+=head2 WWW::CurlOO::Share::Code
+
+WWW::CurlOO::Share setopt method on failure throws a WWW::CurlOO::Share::Code error
+object. It has both numeric value and, when used as string, it calls strerror()
+function to display a nice message.
 
 =head1 SEE ALSO
 
 L<WWW::CurlOO>
 L<WWW::CurlOO::Easy>
 L<WWW::CurlOO::Multi>
-L<WWW::CurlOO::examples(3pm)>
+L<WWW::CurlOO::examples>
 L<libcurl-share(3)>
 L<libcurl-errors(3)>
 
